////////////////////////////////////////////////////////////////////////////////
//
// This file is part of Strata.
//
// Strata is free software: you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// Strata is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// Strata.  If not, see <http://www.gnu.org/licenses/>.
//
// Copyright 2010-2018 Albert Kottke
//
////////////////////////////////////////////////////////////////////////////////

#include "DampingFactory.h"

#include "CustomNonlinearProperty.h"
#include "DarendeliNonlinearProperty.h"

DampingFactory::DampingFactory(QObject *parent)
    : AbstractNonlinearPropertyFactory(parent)
{
    _type = NonlinearProperty::Damping;
    _models
            << new CustomNonlinearProperty(_type, false)

            << new DarendeliNonlinearProperty(_type)

            << new NonlinearProperty(
                    "EPRI (93), PI=10",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 0.991 << 1.054 << 1.122 << 1.337 << 1.639 <<
                    2.040 << 2.890 << 3.981 << 5.585 << 7.733 << 10.388 << 13.339 << 16.412 <<
                    19.099 << 20.336 << 19.936 )

            << new NonlinearProperty(
                    "EPRI (93), PI=30",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.428 << 1.420 << 1.423 << 1.513 << 1.600 << 1.743 <<
                    2.026 << 2.480 << 3.095 << 4.113 << 5.643 << 7.744 << 10.295 << 13.199 <<
                    16.085 << 18.394 << 18.956 )

            << new NonlinearProperty(
                    "EPRI (93), PI=50",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.928 << 1.920 << 1.911 << 1.973 << 1.965 << 2.037 <<
                    2.142 << 2.348 << 2.773 << 3.346 << 4.330 << 5.778 << 7.759 << 10.214 <<
                    12.931 << 15.617 << 17.429 )

            << new NonlinearProperty(
                    "EPRI (93), PI=70",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 2.500 << 2.491 << 2.411 << 2.402 << 2.393 << 2.411 <<
                    2.446 << 2.545 << 2.662 << 2.937 << 3.365 << 4.119 << 5.279 << 6.966 << 9.111
                    << 11.421 << 13.704 )

            << new NonlinearProperty(
                    "EPRI (93), 0-20 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.429 << 1.476 << 1.536 << 1.602 << 1.879 << 2.193 <<
                    2.819 << 3.724 << 5.066 << 6.940 << 9.346 << 12.201 << 15.443 << 18.703 <<
                    21.704 << 24.541 << 27.217 )

            << new NonlinearProperty(
                    "EPRI (93), 20-50 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.142 << 1.196 << 1.250 << 1.304 << 1.469 << 1.670 <<
                    2.074 << 2.658 << 3.622 << 5.066 << 7.069 << 9.569 << 12.500 << 15.688 <<
                    19.004 << 22.022 << 24.699 )

            << new NonlinearProperty(
                    "EPRI (93), 50-120 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 0.982 << 0.978 << 1.122 << 1.165 << 1.371 <<
                    1.610 << 2.046 << 2.830 << 3.901 << 5.493 << 7.662 << 10.381 << 13.383 <<
                    16.643 << 19.766 << 22.580 )

            << new NonlinearProperty(
                    "EPRI (93), 120-250 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 0.857 << 0.839 << 0.821 << 0.880 << 1.006 << 1.125 <<
                    1.341 << 1.629 << 2.198 << 3.131 << 4.460 << 6.281 << 8.686 << 11.573 <<
                    14.770 << 17.879 << 20.906 )

            << new NonlinearProperty(
                    "EPRI (93), 250-500 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 0.786 << 0.792 << 0.799 << 0.811 << 0.867 << 0.950 <<
                    1.081 << 1.344 << 1.774 << 2.515 << 3.520 << 5.077 << 7.206 << 9.853 <<
                    12.839 << 15.972 << 19.072 )

            << new NonlinearProperty(
                    "EPRI (93), 500-1000 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 0.492 << 0.554 << 0.607 << 0.589 << 0.643 << 0.696 <<
                    0.772 << 0.983 << 1.234 << 1.735 << 2.562 << 3.696 << 5.408 << 7.617 <<
                    10.428 << 13.524 << 16.459 )

            << new NonlinearProperty(
                    "GEI (83), 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.500 << 1.750 << 3.850 << 7.750 <<
                    13.100 << 18.750 << 23.000 << 26.000 << 26.000 )

            << new NonlinearProperty(
                    "GEI (83), 50-100 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.500 << 1.600 << 3.150 << 6.500 <<
                    11.750 << 17.750 << 22.500 << 25.600 << 25.600 )

            << new NonlinearProperty(
                    "GEI (83), 100-250 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.500 << 1.500 << 2.500 << 5.000 <<
                    10.000 << 16.500 << 22.000 << 25.400 << 25.400 )

            << new NonlinearProperty(
                    "GEI (83), 250-500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.500 << 1.500 << 2.100 << 3.750 <<
                    8.250 << 14.750 << 20.500 << 24.250 << 24.250 )

            << new NonlinearProperty(
                    "GEI (83), >500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.500 << 1.500 << 1.750 << 2.500 <<
                    6.250 << 13.000 << 19.000 << 23.100 << 23.100 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 2.100 << 2.100 << 2.500 << 2.500 << 3.730 << 6.560 <<
                    11.230 << 15.980 << 21.090 << 24.110 << 24.110 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), 50-150 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.520 << 1.950 << 2.950 << 4.730 <<
                    8.570 << 13.070 << 18.590 << 24.110 << 24.110 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), 150-300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.500 << 1.500 << 1.520 << 1.680 << 2.250 << 3.220 <<
                    6.190 << 10.270 << 15.660 << 24.110 << 24.110 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), >300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 0.960 << 0.980 << 1.010 << 1.010 << 1.070 << 1.560 <<
                    4.150 << 7.840 << 12.080 << 17.840 << 17.840 )

            << new NonlinearProperty(
                    "Idriss (1990), Sand",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 0.240 << 0.440 << 0.800 << 1.460 << 2.800 << 5.310 <<
                    9.800 << 15.740 << 21.000 << 21.000 << 21.000 )

            << new NonlinearProperty(
                    "Idriss (1990), Clay",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 0.240 << 0.440 << 0.800 << 1.460 << 2.800 << 5.310 <<
                    9.800 << 15.740 << 21.000 << 21.000 << 21.000 )

            << new NonlinearProperty(
                    "Imperial Valley Soils, 0-300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 0.950 << 0.950 << 0.950 << 0.950 << 1.220 << 2.030 <<
                    4.060 << 7.980 << 12.040 )

            << new NonlinearProperty(
                    "Imperial Valley Soils, >300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 0.540 << 0.540 << 0.540 << 0.540 << 0.540 << 0.950 <<
                    2.710 << 5.950 << 9.870 )

            << new NonlinearProperty(
                    "Peninsular Range, Cohesionless 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 1.060 << 1.060 << 1.210 << 1.660 << 2.880 << 5.600 <<
                    10.590 << 16.650 << 23.000 )

            << new NonlinearProperty(
                    "Peninsular Range, Cohesionless 50-500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 0.600 << 0.600 << 0.600 << 0.910 << 1.210 << 2.580 <<
                    5.450 << 10.590 << 16.650 )

            << new NonlinearProperty(
                    "Seed & Idriss, Sand Lower",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 0.50 << 0.60 << 0.80 << 1.40 << 2.80 << 5.30 << 10.00 <<
                    15.80 << 21.50 )

            << new NonlinearProperty(
                    "Seed & Idriss, Sand Mean",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 0.57 << 0.86 << 1.70 << 3.10 << 5.50 << 9.50 << 15.50 <<
                    21.10 << 24.60 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 0",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 3.00 << 5.40 << 9.80 << 15.00 <<
                    20.30 << 24.00 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 15",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 2.60 << 4.50 << 7.50 << 11.60 <<
                    16.00 << 20.00 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 30",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 2.10 << 3.80 << 5.90 << 8.80 <<
                    12.50 << 16.90 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 50",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 1.80 << 2.90 << 4.30 << 6.20 <<
                    9.50 << 13.50 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 100",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 1.50 << 2.00 << 2.90 << 4.10 <<
                    6.20 << 9.80 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 200",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.10 << 1.30 << 1.60 << 2.10 << 3.00 <<
                    4.80 << 8.10 );
}
