////////////////////////////////////////////////////////////////////////////////
//
// This file is part of Strata.
//
// Strata is free software: you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// Strata is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// Strata.  If not, see <http://www.gnu.org/licenses/>.
//
// Copyright 2010-2018 Albert Kottke
//
////////////////////////////////////////////////////////////////////////////////

#include "MaxErrorProfileOutput.h"

#include "AbstractCalculator.h"
#include "OutputStatistics.h"
#include "SoilProfile.h"
#include "Units.h"

#include <qwt_scale_engine.h>

MaxErrorProfileOutput::MaxErrorProfileOutput(OutputCatalog* catalog)
    : AbstractSteppedProfileOutput(catalog)
{
    _statistics = 0;
}

auto MaxErrorProfileOutput::name() const -> QString
{
    return tr("Maximum Error Profile");
}

auto MaxErrorProfileOutput::shortName() const -> QString
{
    return tr("dispTs");
}

auto MaxErrorProfileOutput::xLabel() const -> const QString
{
    return tr("Maximum Error (%)");
}

auto MaxErrorProfileOutput::xScaleEngine() const -> QwtScaleEngine*
{
    return new QwtLinearScaleEngine;
}

void MaxErrorProfileOutput::extract(AbstractCalculator* const calculator,
                         QVector<double> & ref, QVector<double> & data) const
{
    AbstractSteppedProfileOutput::extract(calculator, ref, data);

    data = calculator->site()->maxErrorProfile();
}
