////////////////////////////////////////////////////////////////////////////////
//
// This file is part of Strata.
//
// Strata is free software: you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// Strata is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// Strata.  If not, see <http://www.gnu.org/licenses/>.
//
// Copyright 2010-2018 Albert Kottke
//
////////////////////////////////////////////////////////////////////////////////

#include "ModulusFactory.h"

#include "CustomNonlinearProperty.h"
#include "DarendeliNonlinearProperty.h"
#include "NonlinearProperty.h"

ModulusFactory::ModulusFactory(QObject *parent)
    : AbstractNonlinearPropertyFactory(parent)
{
    _type = NonlinearProperty::ModulusReduction;
    _models
            << new CustomNonlinearProperty(_type, false)

            << new DarendeliNonlinearProperty(_type)

            << new NonlinearProperty(
                    "EPRI (93) PI=10",
                    NonlinearProperty::ModulusReduction,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 0.998 << 0.993 << 0.977 << 0.951 <<
                    0.905 << 0.839 << 0.746 << 0.626 << 0.495 << 0.364 << 0.244 << 0.158 << 0.092
                    << 0.052 << 0.032)

            << new NonlinearProperty(
                    "EPRI (93), PI=30",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 1.000 << 0.997 << 0.990 <<
                    0.968 << 0.931 << 0.872 << 0.784 << 0.671 << 0.543 << 0.409 << 0.288 << 0.188
                    << 0.117 << 0.074 )

            << new NonlinearProperty(
                    "EPRI (93), PI=50",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 <<
                    0.996 << 0.981 << 0.951 << 0.897 << 0.821 << 0.714 << 0.585 << 0.451 << 0.330
                    << 0.224 << 0.153 )

            << new NonlinearProperty(
                    "EPRI (93), PI=70",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 <<
                    1.000 << 1.000 << 0.996 << 0.976 << 0.937 << 0.877 << 0.785 << 0.671 << 0.536
                    << 0.408 << 0.299 )

            << new NonlinearProperty(
                    "EPRI (93), 0-20 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 0.998 << 0.986 << 0.960 <<
                    0.920 << 0.851 << 0.759 << 0.642 << 0.515 << 0.392 << 0.278 << 0.189 << 0.121
                    << 0.073 << 0.043 )

            << new NonlinearProperty(
                    "EPRI (93), 20-50 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 0.999 << 0.993 << 0.979 <<
                    0.952 << 0.903 << 0.830 << 0.733 << 0.617 << 0.488 << 0.366 << 0.258 << 0.173
                    << 0.108 << 0.066 )

            << new NonlinearProperty(
                    "EPRI (93), 50-120 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 0.999 << 0.998 << 0.988 <<
                    0.970 << 0.934 << 0.878 << 0.797 << 0.691 << 0.567 << 0.444 << 0.328 << 0.225
                    << 0.145 << 0.092 )

            << new NonlinearProperty(
                    "EPRI (93), 120-250 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 0.999 << 0.999 << 0.994 <<
                    0.979 << 0.954 << 0.909 << 0.840 << 0.747 << 0.631 << 0.507 << 0.384 << 0.274
                    << 0.182 << 0.118 )

            << new NonlinearProperty(
                    "EPRI (93), 250-500 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 0.999 << 0.999 << 0.999 <<
                    0.986 << 0.968 << 0.934 << 0.879 << 0.799 << 0.696 << 0.575 << 0.449 << 0.332
                    << 0.230 << 0.148 )

            << new NonlinearProperty(
                    "EPRI (93), 500-1000 ft",
                    _type,
                    QVector<double>() << 1.000e-04 << 1.778e-04 << 3.162e-04 << 5.623e-04 <<
                    1.000e-03 << 1.778e-03 << 3.162e-03 << 5.623e-03 << 1.000e-02 << 1.778e-02 <<
                    3.162e-02 << 5.623e-02 << 1.000e-01 << 1.778e-01 << 3.162e-01 << 5.623e-01 <<
                    1.000e+00,
                    QVector<double>() << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 << 1.000 <<
                    0.995 << 0.982 << 0.960 << 0.915 << 0.850 << 0.765 << 0.660 << 0.532 << 0.410
                    << 0.297 << 0.200 )

            << new NonlinearProperty(
                    "GEI (83), 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.990 << 0.980 << 0.910 << 0.780 << 0.560 <<
                    0.330 << 0.160 << 0.065 << 0.040 << 0.040 )

            << new NonlinearProperty(
                    "GEI (83), 50-100 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.990 << 0.980 << 0.935 << 0.816 << 0.610 <<
                    0.360 << 0.175 << 0.065 << 0.040 << 0.040 )

            << new NonlinearProperty(
                    "GEI (83), 100-250 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.990 << 0.980 << 0.947 << 0.852 << 0.670 <<
                    0.425 << 0.200 << 0.065 << 0.040 << 0.040 )

            << new NonlinearProperty(
                    "GEI (83), 250-500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.995 << 0.990 << 0.965 << 0.890 << 0.725 <<
                    0.495 << 0.240 << 0.080 << 0.040 << 0.040 )

            << new NonlinearProperty(
                    "GEI (83), >500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 0.985 << 0.925 << 0.775 <<
                    0.565 << 0.300 << 0.100 << 0.040 << 0.040 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.991 << 0.985 << 0.943 << 0.854 << 0.688 <<
                    0.454 << 0.259 << 0.100 << 0.052 << 0.052 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), 50-150 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 0.998 << 0.999 << 0.975 << 0.900 << 0.767 <<
                    0.536 << 0.319 << 0.134 << 0.052 << 0.052 )

            << new NonlinearProperty(
                    "GeoMatrix (1990), >150 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 0.999 << 0.939 << 0.826 <<
                    0.620 << 0.381 << 0.162 << 0.052 << 0.052 )

            << new NonlinearProperty(
                    "Idriss (1990), Clay",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 0.979 << 0.941 << 0.839 <<
                    0.656 << 0.429 << 0.238 << 0.238 << 0.238 )

            << new NonlinearProperty(
                    "Idriss (1990), Sand",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00 << 3.162e+00 <<
                    1.000e+01,
                    QVector<double>()  << 1.000 << 1.000 << 0.990 << 0.955 << 0.850 << 0.628 <<
                    0.370 << 0.176 << 0.080 << 0.080 << 0.080 )

            << new NonlinearProperty(
                    "Imperial Valley Soils, 0-300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 1.000 << 0.973 << 0.904 <<
                    0.699 << 0.459 << 0.247 )

            << new NonlinearProperty(
                    "Imperial Valley Soils, >300 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 1.000 << 0.986 << 0.952 <<
                    0.767 << 0.541 << 0.329 )

            << new NonlinearProperty(
                    "Iwasaki, 0.25 atm",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 0.98 << 0.93 << 0.85 << 0.72 << 0.49 << 0.23 <<
                    0.08 << 0.03 )

            << new NonlinearProperty(
                    "Iwasaki, 1.0 atm",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 0.97 << 0.92 << 0.83 << 0.65 << 0.39 <<
                    0.17 << 0.07 )

            << new NonlinearProperty(
                    "Peninsular Range, Cohesionless 0-50 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 0.963 << 0.868 << 0.677 <<
                    0.427 << 0.221 << 0.088 )

            << new NonlinearProperty(
                    "Peninsular Range, Cohesionless 50-500 ft",
                    _type,
                    QVector<double>()  << 1.000e-04 << 3.162e-04 << 1.000e-03 << 3.162e-03 <<
                    1.000e-02 << 3.162e-02 << 1.000e-01 << 3.162e-01 << 1.000e+00,
                    QVector<double>()  << 1.000 << 1.000 << 1.000 << 0.985 << 0.941 << 0.846 <<
                    0.647 << 0.404 << 0.191 )

            << new NonlinearProperty(
                    "Seed & Idriss, Sand Mean",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 0.99 << 0.96 << 0.88 << 0.74 << 0.52 << 0.29 <<
                    0.15 << 0.06 )

            << new NonlinearProperty(
                    "Seed & Idriss, Sand Upper",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 0.99 << 0.94 << 0.84 << 0.65 << 0.36 <<
                    0.19 << 0.08 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 0",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 0.96 << 0.88 << 0.70 << 0.47 << 0.26 <<
                    0.11 << 0.03 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 15",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 0.99 << 0.94 << 0.81 << 0.64 << 0.41 <<
                    0.22 << 0.10 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 30",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 0.98 << 0.90 << 0.75 << 0.53 <<
                    0.35 << 0.17 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 50",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 <<1.00 << 1.00 << 1.00 << 0.95 << 0.84 << 0.67 <<
                    0.47 << 0.25 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 100",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 1.00 << 0.98 << 0.92 << 0.81 <<
                    0.63 << 0.37 )

            << new NonlinearProperty(
                    "Vucetic & Dobry, PI = 200",
                    _type,
                    QVector<double>() << 1.00e-04 << 3.16e-04 << 1.00e-03 << 3.16e-03 << 1.00e-02
                    << 3.16e-02 << 1.00e-01 << 3.16e-01 << 1.00e+00,
                    QVector<double>() << 1.00 << 1.00 << 1.00 << 1.00 << 1.00 << 0.96 << 0.89 <<
                    0.75 << 0.53 );
}
